@@ -18,6 +18,8 @@ if __name__ == '__main__':
             help = 'The output is a list and printed accordingly')
     argument.add_argument('-i', '--input', default = 'nil', 
             help = 'The main function gets this expression as argument, default to nil')
+    argument.add_argument('-t', '--trace',  action="store_true",
+            help = 'Prints the complete trace of the program in the end.')
     args = argument.parse_args()
     progs = []
     for f in args.files:
@@ -26,4 +28,8 @@ if __name__ == '__main__':
     context = pywhile.Context(progs)
     input = context.executeExpression(pywhile.parseExpression(args.input)[0])
     last_name = progs[-1].name
-    print args.output(context.executeProgram(last_name, input))
+    ret = context.executeProgram(last_name, input)
+    print args.output(ret)
+    if args.trace:
+        for s in context.trace:
+            print "* {}".format(s)
